LiqColorPickerButton class final

iOS 26 color-picker button — conic-gradient ring with an inset swatch.

Sourced from native/components/color-pickers.css (.ios26-colorpickers-picker-button). Renders a 36 or 28pt circle with a hue conic gradient and the chosen color inset 5pt.

Inheritance

Constructors

LiqColorPickerButton({required Color color, VoidCallback? onPressed, LiqColorPickerButtonSize size = LiqColorPickerButtonSize.large, Key? key})
Creates a color-picker button.
const

Properties

color Color
Currently chosen color (rendered inset).
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed VoidCallback?
Tap callback.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size LiqColorPickerButtonSize
Visual size.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LiqColorPickerButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

tapTargetSize → const double
Minimum tap target size.