LiqMenuQuickAction class final
Compact icon+label action rendered in the top strip of LiqMenu.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LiqMenuQuickAction
- Mixed-in types
Constructors
- LiqMenuQuickAction({required String label, required Widget icon, VoidCallback? onPressed, bool destructive = false, bool selected = false, Brightness? brightness, Key? key})
-
Creates a quick action.
const
Properties
- brightness → Brightness?
-
Surface brightness. Defaults to the nearest liqkit theme brightness.
final
- destructive → bool
-
Whether the action uses the destructive red accent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget
-
Icon rendered above label.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
Action label.
final
- onPressed → VoidCallback?
-
Tap callback. Null renders a disabled/empty quick action.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
Whether the action uses the selected quick-action fill.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LiqMenuQuickAction> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited