LiqTabSegmentedControl<T> class final

Tab-style segmented control — a row of labels with an animated underline indicator under the selected one. Borderless. Used for in-page tab navigation (Overview / Details / Reviews etc.).

Inheritance
Mixed-in types

Constructors

LiqTabSegmentedControl({required T value, required List<LiqSegmentItem<T>> segments, required ValueChanged<T>? onChanged, Color? indicatorColor, double height = 44, Key? key})
Creates a tab segmented control.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
final
indicatorColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<T>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<LiqSegmentItem<T>>
final
value → T
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited