LiqResizableDirection enum
Axis along which a LiqResizable arranges its two panes.
Values
- horizontal → const LiqResizableDirection
-
Panes are arranged left-to-right with a vertical divider between them; dragging the divider adjusts the horizontal split ratio.
- vertical → const LiqResizableDirection
-
Panes are arranged top-to-bottom with a horizontal divider between them; dragging the divider adjusts the vertical split ratio.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LiqResizableDirection> - A constant List of the values in this enum, in order of their declaration.